
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/WebService/MinFraud.pm',
    'lib/WebService/MinFraud/Client.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/DateTime/RFC3339.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/Enum.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/Hex32.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/Hostname.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/IPAddress.pm',
    'lib/WebService/MinFraud/Data/Rx/Type/WebURI.pm',
    'lib/WebService/MinFraud/Error/Generic.pm',
    'lib/WebService/MinFraud/Error/HTTP.pm',
    'lib/WebService/MinFraud/Error/IPAddressNotFound.pm',
    'lib/WebService/MinFraud/Error/WebService.pm',
    'lib/WebService/MinFraud/Example.pod',
    'lib/WebService/MinFraud/Model/Insights.pm',
    'lib/WebService/MinFraud/Model/Score.pm',
    'lib/WebService/MinFraud/Record/BillingAddress.pm',
    'lib/WebService/MinFraud/Record/Country.pm',
    'lib/WebService/MinFraud/Record/CreditCard.pm',
    'lib/WebService/MinFraud/Record/IPAddress.pm',
    'lib/WebService/MinFraud/Record/Issuer.pm',
    'lib/WebService/MinFraud/Record/Location.pm',
    'lib/WebService/MinFraud/Record/ShippingAddress.pm',
    'lib/WebService/MinFraud/Record/Warning.pm',
    'lib/WebService/MinFraud/Role/Data/Rx/Type.pm',
    'lib/WebService/MinFraud/Role/Error/HTTP.pm',
    'lib/WebService/MinFraud/Role/HasCommonAttributes.pm',
    'lib/WebService/MinFraud/Role/HasLocales.pm',
    'lib/WebService/MinFraud/Role/Model.pm',
    'lib/WebService/MinFraud/Role/Record/Address.pm',
    'lib/WebService/MinFraud/Types.pm',
    'lib/WebService/MinFraud/Validator.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/WebService/MinFraud/Model/Insights.t',
    't/WebService/MinFraud/Model/Score.t',
    't/WebService/MinFraud/Record/BillingAddress.t',
    't/WebService/MinFraud/Record/CreditCard.t',
    't/WebService/MinFraud/Record/Issuer.t',
    't/WebService/MinFraud/Record/ShippingAddress.t',
    't/WebService/MinFraud/Record/Warning.t',
    't/WebService/MinFraud/Validator.t',
    't/author-00-compile.t',
    't/author-basic.t',
    't/author-eol.t',
    't/author-no-tabs.t',
    't/author-pod-spell.t',
    't/data/full-request.json',
    't/data/insights-response.json',
    't/data/score-response.json',
    't/lib/Test/WebService/MinFraud.pm',
    't/release-cpan-changes.t',
    't/release-pod-coverage.t',
    't/release-pod-syntax.t',
    't/release-portability.t',
    't/release-synopsis.t',
    't/release-test-version.t',
    't/release-tidyall.t'
);

notabs_ok($_) foreach @files;
done_testing;
