
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Alders
Alders'
Eilam
Eilam's
MaxMind
MaxMind's
Oschwald
Oschwald's
Rolsky
Rolsky's
ASN
API
APIs
AdWords
CN
GEONAMES
GeoIP
GeoLite
GeoNames
GitHub
IANA
IP
IP's
IPv
ISP
Knop
minFraud
OC
Omni
Oxfordshire
SSL
URI
VERSIONING
VPN
YYY
YYYZZZ
cpanm
contentDeliveryNetwork
de
dialup
downloadable
ergument
geoname_id
hostname
ip
ja
libmaxminddb
lookup
maxmind
omni
params
routable
ru
searchEngineSpider
ua
unpopulated
versioning
zh
Mateu
Hunter
mhunter
Inc
Andy
Jack
ajack
lib
WebService
MinFraud
Client
Data
Rx
Type
DateTime
RFC3339
Enum
Hex32
Hostname
IPAddress
WebURI
Error
Generic
HTTP
IPAddressNotFound
Example
Model
Insights
Score
Record
BillingAddress
Country
CreditCard
Issuer
Location
ShippingAddress
Warning
Role
HasCommonAttributes
HasLocales
Address
Types
Validator
